@@ -38,8 +38,8 @@
 using namespace FollowUpReminder;
 
 FollowUpReminderManager::FollowUpReminderManager(QObject *parent)
-    : QObject(parent),
-      mInitialize(false)
+    : QObject(parent)
+    , mInitialize(false)
 {
     mConfig = KSharedConfig::openConfig();
 }
@@ -59,7 +59,6 @@ void FollowUpReminderManager::load(bool forceReloadConfig)
     const int numberOfItems = itemList.count();
     QList<FollowUpReminder::FollowUpReminderInfo *> noAnswerList;
     for (int i = 0; i < numberOfItems; ++i) {
-
         KConfigGroup group = mConfig->group(itemList.at(i));
 
         FollowUpReminderInfo *info = new FollowUpReminderInfo(group);
@@ -121,7 +120,7 @@ void FollowUpReminderManager::checkFollowUp(const Akonadi::Item &item, const Ako
 
 void FollowUpReminderManager::slotCheckFollowUpFinished(const QString &messageId, Akonadi::Item::Id id)
 {
-    Q_FOREACH (FollowUpReminderInfo *info, mFollowUpReminderInfoList) {
+    for (FollowUpReminderInfo *info : qAsConst(mFollowUpReminderInfoList)) {
         qCDebug(FOLLOWUPREMINDERAGENT_LOG) << "FollowUpReminderManager::slotCheckFollowUpFinished info:" << info;
         if (!info) {
             continue;
@@ -162,7 +161,6 @@ void FollowUpReminderManager::answerReceived(const QString &from)
                          nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("akonadi_followupreminder_agent"));
-
 }
 
 QString FollowUpReminderManager::printDebugInfo()
@@ -171,7 +169,7 @@ QString FollowUpReminderManager::printDebugInfo()
     if (mFollowUpReminderInfoList.isEmpty()) {
         infoStr = QStringLiteral("No mail");
     } else {
-        Q_FOREACH (FollowUpReminder::FollowUpReminderInfo *info, mFollowUpReminderInfoList) {
+        for (FollowUpReminder::FollowUpReminderInfo *info : qAsConst(mFollowUpReminderInfoList)) {
             if (!infoStr.isEmpty()) {
                 infoStr += QLatin1Char('\n');
             }
@@ -183,8 +181,7 @@ QString FollowUpReminderManager::printDebugInfo()
 
 QString FollowUpReminderManager::infoToStr(FollowUpReminder::FollowUpReminderInfo *info)
 {
-    QString infoStr;
-    infoStr = QStringLiteral("****************************************");
+    QString infoStr = QStringLiteral("****************************************");
     infoStr += QStringLiteral("Akonadi Item id :%1\n").arg(info->originalMessageItemId());
     infoStr += QStringLiteral("MessageId :%1\n").arg(info->messageId());
     infoStr += QStringLiteral("Subject :%1\n").arg(info->subject());
@@ -194,4 +191,3 @@ QString FollowUpReminderManager::infoToStr(FollowUpReminder::FollowUpReminderInf
     infoStr += QStringLiteral("****************************************\n");
     return infoStr;
 }
-
