@@ -41,12 +41,13 @@
 #include "messagelist/themecombobox.h"
 #include "messagelist/themeconfigbutton.h"
 
-#include <MailCommon/FolderCollection>
+#include <MailCommon/FolderSettings>
 
 using namespace MailCommon;
 
-CollectionViewPage::CollectionViewPage(QWidget *parent) :
-    CollectionPropertiesPage(parent), mIsLocalSystemFolder(false)
+CollectionViewPage::CollectionViewPage(QWidget *parent)
+    : CollectionPropertiesPage(parent)
+    , mIsLocalSystemFolder(false)
 {
     setObjectName(QStringLiteral("KMail::CollectionViewPage"));
     setPageTitle(i18nc("@title:tab View settings for a folder.", "View"));
@@ -59,7 +60,7 @@ CollectionViewPage::~CollectionViewPage()
 void CollectionViewPage::init(const Akonadi::Collection &col)
 {
     mCurrentCollection = col;
-    mFolderCollection = FolderCollection::forCollection(col);
+    mFolderCollection = FolderSettings::forCollection(col);
     mIsLocalSystemFolder = CommonKernel->isSystemFolderCollection(col) || mFolderCollection->isStructural() || Kernel::folderIsInbox(col);
 
     QVBoxLayout *topLayout = new QVBoxLayout(this);
@@ -297,10 +298,10 @@ void CollectionViewPage::save(Akonadi::Collection &col)
     const int currentIndex = mShowSenderReceiverComboBox->currentIndex();
     if (mShowSenderReceiverValue != currentIndex) {
         if (currentIndex == 1) {
-            Akonadi::MessageFolderAttribute *messageFolder  = col.attribute<Akonadi::MessageFolderAttribute>(Akonadi::Collection::AddIfMissing);
+            Akonadi::MessageFolderAttribute *messageFolder = col.attribute<Akonadi::MessageFolderAttribute>(Akonadi::Collection::AddIfMissing);
             messageFolder->setOutboundFolder(false);
         } else if (currentIndex == 2) {
-            Akonadi::MessageFolderAttribute *messageFolder  = col.attribute<Akonadi::MessageFolderAttribute>(Akonadi::Collection::AddIfMissing);
+            Akonadi::MessageFolderAttribute *messageFolder = col.attribute<Akonadi::MessageFolderAttribute>(Akonadi::Collection::AddIfMissing);
             messageFolder->setOutboundFolder(true);
         } else {
             col.removeAttribute<Akonadi::MessageFolderAttribute>();
@@ -325,4 +326,3 @@ void CollectionViewPage::save(Akonadi::Collection &col)
     }
     mFolderCollection->setFormatMessage(formatMessage);
 }
-
