@@ -48,6 +48,7 @@ struct Icons {
         , checkMailIcon(QIcon::fromTheme(QStringLiteral("mail-receive")))
     {
     }
+
     QPixmap readyPixmap, syncPixmap, errorPixmap, offlinePixmap;
     QIcon checkMailIcon;
 };
@@ -76,7 +77,7 @@ QTextDocument *ConfigAgentDelegate::document(const QStyleOptionViewItem &option,
     const QVariant data = index.model()->data(index, Qt::DecorationRole);
     if (data.isValid() && data.type() == QVariant::Icon) {
         document->addResource(QTextDocument::ImageResource, QUrl(QStringLiteral("agent_icon")),
-                              qvariant_cast<QIcon> (data).pixmap(decorationSize));
+                              qvariant_cast<QIcon>(data).pixmap(decorationSize));
     }
 
     if (!index.data(AgentInstanceModel::OnlineRole).toBool()) {
@@ -102,17 +103,17 @@ QTextDocument *ConfigAgentDelegate::document(const QStyleOptionViewItem &option,
     }
 
     const QString content = QStringLiteral(
-                                "<html style=\"color:%1\">"
-                                "<body>"
-                                "<table>"
-                                "<tr>"
-                                "<td rowspan=\"2\"><img src=\"agent_icon\">&nbsp;&nbsp;</td>"
-                                "<td><b>%2</b></td>"
-                                "</tr>").arg(textColor.name().toUpper()).arg(name)
+        "<html style=\"color:%1\">"
+        "<body>"
+        "<table>"
+        "<tr>"
+        "<td rowspan=\"2\"><img src=\"agent_icon\">&nbsp;&nbsp;</td>"
+        "<td><b>%2</b></td>"
+        "</tr>").arg(textColor.name().toUpper()).arg(name)
                             + QStringLiteral(
-                                "<tr>"
-                                "<td><img src=\"status_icon\"/> %1 %2</td>"
-                                "</tr>").arg(statusMessage).arg(status == 1 ? QStringLiteral("(%1%)").arg(progress) : QLatin1String(""))
+        "<tr>"
+        "<td><img src=\"status_icon\"/> %1 %2</td>"
+        "</tr>").arg(statusMessage).arg(status == 1 ? QStringLiteral("(%1%)").arg(progress) : QLatin1String(""))
                             + QLatin1String("</table></body></html>");
 
     document->setHtml(content);
@@ -168,7 +169,7 @@ QSize ConfigAgentDelegate::sizeHint(const QStyleOptionViewItem &option, const QM
     return QSize(1, qMax(iconHeight, textHeight));    //any width,the view will give us the whole thing in list mode
 }
 
-QWidget* ConfigAgentDelegate::createEditor(QWidget *, const QStyleOptionViewItem &, const QModelIndex &) const
+QWidget *ConfigAgentDelegate::createEditor(QWidget *, const QStyleOptionViewItem &, const QModelIndex &) const
 {
     return nullptr;
 }
@@ -180,8 +181,8 @@ bool ConfigAgentDelegate::editorEvent(QEvent *event, QAbstractItemModel *model,
         return false;
     }
     if (!((event->type() == QEvent::MouseButtonRelease)
-            || (event->type() == QEvent::MouseButtonPress)
-            || (event->type() == QEvent::MouseMove))) {
+          || (event->type() == QEvent::MouseButtonPress)
+          || (event->type() == QEvent::MouseMove))) {
         return false;
     }
 
@@ -191,11 +192,11 @@ bool ConfigAgentDelegate::editorEvent(QEvent *event, QAbstractItemModel *model,
     QStyleOptionButton buttonOpt = buttonOption(option);
 
     if (buttonOpt.rect.contains(mousePos)) {
-
         switch (event->type()) {
         case QEvent::MouseButtonPress:
             return false;
-        case QEvent::MouseButtonRelease: {
+        case QEvent::MouseButtonRelease:
+        {
             QPoint pos = buttonOpt.rect.bottomLeft() + option.rect.topLeft();
             const QString ident = index.data(Akonadi::AgentInstanceModel::InstanceIdentifierRole).toString();
             Q_EMIT optionsClicked(ident, pos);
@@ -212,12 +213,12 @@ void ConfigAgentDelegate::drawFocus(QPainter *painter, const QStyleOptionViewIte
 {
     if (option.state & QStyle::State_HasFocus) {
         QStyleOptionFocusRect o;
-        o.QStyleOption::operator= (option);
+        o.QStyleOption::operator=(option);
         o.rect = rect;
         o.state |= QStyle::State_KeyboardFocusChange;
         QPalette::ColorGroup cg = (option.state & QStyle::State_Enabled) ? QPalette::Normal : QPalette::Disabled;
         o.backgroundColor = option.palette.color(cg, (option.state & QStyle::State_Selected)
-                            ? QPalette::Highlight : QPalette::Background);
+                                                 ? QPalette::Highlight : QPalette::Background);
         QApplication::style()->drawPrimitive(QStyle::PE_FrameFocusRect, &o, painter);
     }
 }
@@ -244,4 +245,3 @@ QStyleOptionButton ConfigAgentDelegate::buttonOption(const QStyleOptionViewItem
 
     return buttonOpt;
 }
-
