@@ -26,26 +26,25 @@
 #include <QAction>
 
 ValidateSendMailShortcut::ValidateSendMailShortcut(KActionCollection *actionCollection, QWidget *parent)
-    : mParent(parent),
-      mActionCollection(actionCollection)
+    : mParent(parent)
+    , mActionCollection(actionCollection)
 {
 }
 
 ValidateSendMailShortcut::~ValidateSendMailShortcut()
 {
-
 }
 
 bool ValidateSendMailShortcut::validate()
 {
     bool sendNow = false;
     const int result = KPIM::PIMMessageBox::fourBtnMsgBox(mParent,
-                       QMessageBox::Question,
-                       i18n("This shortcut allows to send mail directly. Mail can be send accidentally. What do you want to do?"),
-                       i18n("Configure shortcut"),
-                       i18n("Remove Shortcut"),
-                       i18n("Ask Before Sending"),
-                       i18n("Sending Without Confirmation"));
+                                                          QMessageBox::Question,
+                                                          i18n("This shortcut allows to send mail directly. Mail can be send accidentally. What do you want to do?"),
+                                                          i18n("Configure shortcut"),
+                                                          i18n("Remove Shortcut"),
+                                                          i18n("Ask Before Sending"),
+                                                          i18n("Sending Without Confirmation"));
     if (result == KMessageBox::Yes) {
         QAction *act = mActionCollection->action(QStringLiteral("send_mail"));
         if (act) {
