@@ -21,7 +21,7 @@
 #include "folderarchiveaccountinfo.h"
 #include "folderarchivecache.h"
 #include "folderarchiveutil.h"
-#include "helper_p.h"
+
 #include "util.h"
 
 #include <AkonadiCore/AgentManager>
@@ -39,8 +39,8 @@
 #include <QRegularExpression>
 
 FolderArchiveManager::FolderArchiveManager(QObject *parent)
-    : QObject(parent),
-      mCurrentJob(nullptr)
+    : QObject(parent)
+    , mCurrentJob(nullptr)
 {
     mFolderArchiveCache = new FolderArchiveCache(this);
     load();
