@@ -30,7 +30,7 @@
 #include <kxmlguiclient.h>
 #include "messageactions.h"
 #include <kactioncollection.h>
-#include <mailcommon/foldercollection.h>
+#include <mailcommon/foldersettings.h>
 
 #include <QPointer>
 #include <QTimer>
@@ -38,17 +38,14 @@
 #include <AkonadiCore/tag.h>
 #include <MessageList/View>
 
-namespace MailTransport
-{
+namespace MailTransport {
 class Transport;
 }
-namespace Akonadi
-{
+namespace Akonadi {
 class Tag;
 }
 
-namespace KMime
-{
+namespace KMime {
 class Message;
 }
 class QUrl;
@@ -68,28 +65,25 @@ class ManageShowCollectionProperties;
 class KActionMenuTransport;
 class KActionMenuAccount;
 
-namespace KIO
-{
+namespace KIO {
 class Job;
 }
 
-namespace KMail
-{
+namespace KMail {
 class SearchWindow;
 class VacationScriptIndicatorWidget;
 class TagActionManager;
 class FolderShortcutActionManager;
 }
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveDebugDialog;
+class SieveImapPasswordProvider;
 class ManageSieveScriptsDialog;
 class VacationManager;
 }
 
-namespace MailCommon
-{
+namespace MailCommon {
 class FolderSelectionDialog;
 class FavoriteCollectionWidget;
 }
@@ -101,9 +95,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
 public:
     typedef QList<KMMainWidget *> PtrList;
 
-    KMMainWidget(QWidget *parent, KXMLGUIClient *aGUIClient,
-                 KActionCollection *actionCollection,
-                 KSharedConfig::Ptr config = KMKernel::self()->config());
+    KMMainWidget(QWidget *parent, KXMLGUIClient *aGUIClient, KActionCollection *actionCollection, KSharedConfig::Ptr config = KMKernel::self()->config());
     virtual ~KMMainWidget();
     void destruct();
 
@@ -129,33 +121,40 @@ public:
     /** Access to the header list pane. */
     CollectionPane *messageListPane() const;
 
-    QSharedPointer<MailCommon::FolderCollection> currentFolder() const;
+    Akonadi::Collection currentCollection() const;
+    QSharedPointer<MailCommon::FolderSettings> currentFolder() const;
 
     static void cleanup();
     QAction *action(const QString &name)
     {
         return mActionCollection->action(name);
     }
+
     KActionMenu *filterMenu() const
     {
         return mFilterMenu;
     }
+
     KActionMenu *mailingListActionMenu() const
     {
         return mMsgActions->mailingListActionMenu();
     }
+
     QAction *editAction() const
     {
         return mMsgActions->editAction();
     }
+
     QAction *sendAgainAction() const
     {
         return mSendAgainAction;
     }
+
     QAction *sendQueuedAction() const
     {
         return mSendQueued;
     }
+
     KActionMenuTransport *sendQueueViaMenu() const
     {
         return mSendActionMenu;
@@ -316,7 +315,7 @@ protected:
     void moveSelectedMessagesToFolder(const Akonadi::Collection &dest);
     void copySelectedMessagesToFolder(const Akonadi::Collection &dest);
 
-    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *event) override;
 
     KActionCollection *actionCollection() const
     {
@@ -462,7 +461,7 @@ private:
 
     void updateAllToTrashAction(int statistics);
 
-    /** Get Q_DECL_OVERRIDE character encoding. */
+    /** Get override character encoding. */
     QString overrideEncoding() const;
 
     void moveMessageSelected(MessageList::Core::MessageItemSetReference ref, const Akonadi::Collection &dest, bool confirmOnDeletion = true);
@@ -479,10 +478,7 @@ private:
      * Set the status of the messages referenced by the specified set, eventually toggling it.
      * The set parameter must not be null and the ownership is passed to this function.
      */
-    void setMessageSetStatus(const Akonadi::Item::List &select,
-                             const Akonadi::MessageStatus &status,
-                             bool toggle
-                            );
+    void setMessageSetStatus(const Akonadi::Item::List &select, const Akonadi::MessageStatus &status, bool toggle);
     /**
      * Toggles a tag for the messages referenced by the specified set.
      * The set parameter must not be null and the ownership is passed to this function.
@@ -516,7 +512,8 @@ private:
 
     void openFilterDialog(const QByteArray &field, const QString &value);
 
-    void showMessagePopup(const Akonadi::Item &msg, const QUrl &aUrl, const QUrl &imageUrl, const QPoint &aPoint, bool contactAlreadyExists, bool uniqueContactFound, const WebEngineViewer::WebHitTestResult &result);
+    void showMessagePopup(const Akonadi::Item &msg, const QUrl &aUrl, const QUrl &imageUrl, const QPoint &aPoint, bool contactAlreadyExists, bool uniqueContactFound,
+                          const WebEngineViewer::WebHitTestResult &result);
 
 private Q_SLOTS:
     void slotMoveMessageToTrash();
@@ -601,14 +598,14 @@ private:
 
     MailCommon::FavoriteCollectionWidget *mFavoriteCollectionsView;
     Akonadi::FavoriteCollectionsModel *mFavoritesModel;
-    KMReaderWin  *mMsgView;
-    QSplitter    *mSplitter1;
+    KMReaderWin *mMsgView;
+    QSplitter *mSplitter1;
     QSplitter *mSplitter2;
     QSplitter *mFolderViewSplitter;
     Akonadi::Collection mTemplateFolder;
-    bool          mLongFolderList;
-    bool          mStartupDone;
-    bool          mWasEverShown;
+    bool mLongFolderList;
+    bool mStartupDone;
+    bool mWasEverShown;
     bool mHtmlGlobalSetting;
     bool mHtmlLoadExtGlobalSetting;
     bool mFolderHtmlLoadExtPreference;
@@ -649,7 +646,7 @@ private:
     KMail::MessageActions *mMsgActions;
     Akonadi::StandardMailActionManager *mAkonadiStandardActionManager;
     CollectionPane *mMessagePane;
-    QSharedPointer<MailCommon::FolderCollection> mCurrentFolder;
+    QSharedPointer<MailCommon::FolderSettings> mCurrentFolderSettings;
 
     MailCommon::FolderTreeWidget *mFolderTreeWidget;
 
@@ -660,6 +657,7 @@ private:
 
     QTimer mCheckMailTimer;
 
+    KSieveUi::SieveImapPasswordProvider *mSievePasswordProvider;
     QPointer<MailCommon::FolderSelectionDialog> mMoveOrCopyToDialog;
     QPointer<MailCommon::FolderSelectionDialog> mSelectFromAllFoldersDialog;
     QAction *mServerSideSubscription;
@@ -680,4 +678,3 @@ private:
 };
 
 #endif
-
