@@ -28,15 +28,13 @@
 
 #include <KCModule>
 #include <KViewStateMaintainer>
-namespace Akonadi
-{
+namespace Akonadi {
 class ETMViewStateSaver;
 }
 
 class QCheckBox;
 
-namespace PimCommon
-{
+namespace PimCommon {
 class CheckedCollectionWidget;
 }
 
@@ -47,9 +45,9 @@ class KCMKMailSummary : public KCModule
 public:
     explicit KCMKMailSummary(QWidget *parent = nullptr);
 
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
 
 private Q_SLOTS:
     void modified();
