@@ -53,9 +53,11 @@ using KPIM::BroadcastStatus;
 #include <QVBoxLayout>
 #include <QLocale>
 
-SummaryViewPart::SummaryViewPart(KontactInterface::Core *core,
-                                 const KAboutData &aboutData, QObject *parent)
-    : KParts::ReadOnlyPart(parent), mCore(core), mFrame(nullptr), mConfigAction(nullptr)
+SummaryViewPart::SummaryViewPart(KontactInterface::Core *core, const KAboutData &aboutData, QObject *parent)
+    : KParts::ReadOnlyPart(parent)
+    , mCore(core)
+    , mFrame(nullptr)
+    , mConfigAction(nullptr)
 {
     Q_UNUSED(aboutData);
     loadLayout();
@@ -118,8 +120,7 @@ void SummaryViewPart::updateWidgets()
 
     delete mFrame;
 
-    KIdentityManagement::IdentityManager idm(true, this);
-    const KIdentityManagement::Identity &id = idm.defaultIdentity();
+    const KIdentityManagement::Identity &id = KIdentityManagement::IdentityManager::self()->defaultIdentity();
 
     QString currentUser = i18n("Summary for %1", id.fullName());
     mUsernameLabel->setText(QStringLiteral("<b>%1</b>").arg(currentUser));
@@ -168,8 +169,8 @@ void SummaryViewPart::updateWidgets()
                 connect(summary, &KontactInterface::Summary::summaryWidgetDropped,
                         this, &SummaryViewPart::summaryWidgetMoved);
 
-                if (!mLeftColumnSummaries.contains(plugin->identifier()) &&
-                        !mRightColumnSummaries.contains(plugin->identifier())) {
+                if (!mLeftColumnSummaries.contains(plugin->identifier())
+                    && !mRightColumnSummaries.contains(plugin->identifier())) {
                     mLeftColumnSummaries.append(plugin->identifier());
                 }
 
@@ -258,8 +259,8 @@ void SummaryViewPart::summaryWidgetMoved(QWidget *target, QObject *obj, int alig
             return;
         }
     } else {
-        if ((mLeftColumn->indexOf(target) == -1 && mRightColumn->indexOf(target) == -1) ||
-                (mLeftColumn->indexOf(widget) == -1 && mRightColumn->indexOf(widget) == -1)) {
+        if ((mLeftColumn->indexOf(target) == -1 && mRightColumn->indexOf(target) == -1)
+            || (mLeftColumn->indexOf(widget) == -1 && mRightColumn->indexOf(widget) == -1)) {
             return;
         }
     }
